summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
-rw-r--r--qpid/java/broker/src/main/java/org/apache/qpid/server/queue/ManagedQueue.java6
1 files changed, 3 insertions, 3 deletions
diff --git a/qpid/java/broker/src/main/java/org/apache/qpid/server/queue/ManagedQueue.java b/qpid/java/broker/src/main/java/org/apache/qpid/server/queue/ManagedQueue.java
index 53e249f210..d91d45a446 100644
--- a/qpid/java/broker/src/main/java/org/apache/qpid/server/queue/ManagedQueue.java
+++ b/qpid/java/broker/src/main/java/org/apache/qpid/server/queue/ManagedQueue.java
@@ -116,18 +116,18 @@ public interface ManagedQueue
boolean isAutoDelete() throws IOException;
/**
* Returns the maximum age of a message (expiration time)
* @return the maximum age
* @throws IOException
*/
Long getMaximumMessageAge() throws IOException;
/**
* Sets the maximum age of a message
* @param age maximum age of message.
* @throws IOException
*/
- @MBeanAttribute(name="MaximumMessageAge", description="Threshold high value for message age on the broker")
+ @MBeanAttribute(name="MaximumMessageAge", description="Threshold high value(milliseconds) for message age")
void setMaximumMessageAge(Long age) throws IOException;
/**
@@ -116,18 +116,18 @@ public interface ManagedQueue
boolean isAutoDelete() throws IOException;
/**
- * Returns the maximum age of a message (expiration time)
+ * Returns the maximum age of a message (expiration time) in milliseconds
* @return the maximum age
* @throws IOException
@@ -116,18 +116,18 @@ public interface ManagedQueue
Long getMaximumMessageAge() throws IOException;
/**
- * Sets the maximum age of a message
+ * Sets the maximum age of a message in milliseconds
* @param age maximum age of message.
* @throws IOException